2022-03-21 Version: 1.1.5
- Generated python2 2020-05-18 for dataworks-public.

2022-02-28 Version: 1.1.4
- Generated python2 2020-05-18 for dataworks-public.

2021-12-06 Version: 1.1.3
- Generated python2 2020-05-18 for dataworks-public.

2021-10-21 Version: 1.1.2
- Generated python2 2020-05-18 for dataworks-public.

2021-10-21 Version: 1.1.1
- Generated python2 2020-05-18 for dataworks-public.

2021-09-10 Version: 1.1.0
- Generated python2 2020-05-18 for dataworks-public.

2021-08-20 Version: 1.0.1
- Generated python2 2020-05-18 for dataworks-public.

2021-05-20 Version: 1.0.0
- Generated python2 2020-05-18 for dataworks-public.

